#
# spec file for package scdl
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pythons python3
Name:           scdl
Version:        2.12.1
Release:        2.3
Summary:        Souncloud Music Downloader
License:        GPL-2.0-only
Group:          Productivity/Multimedia/Other
URL:            https://github.com/scdl-org/scdl
Source:         https://files.pythonhosted.org/packages/source/s/scdl/scdl-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  python3-base >= 3.7
BuildRequires:  python3-pip
BuildRequires:  python3-setuptools
BuildRequires:  python3-wheel
Requires:       ffmpeg
Requires:       python3-docopt-ng
Requires:       python3-filelock >= 3.0
Requires:       python3-mutagen >= 1.45
Requires:       python3-pathvalidate
Requires:       python3-requests
Requires:       python3-soundcloud-v2 >= 1.5.2
Requires:       python3-termcolor
Requires:       python3-tqdm
BuildArch:      noarch

%description
The program can download music from SoundCloud and set id3tag to the downloaded music.

%prep
%setup -q
sed -i '1s/^#!.*//' scdl/scdl.py
chmod -x README.md

%build
%pyproject_wheel

%install
%pyproject_install
# do not install tests
rm -r %{buildroot}%{python3_sitelib}/tests
%fdupes %{buildroot}%{python3_sitelib}

%check
exit 0

%files
%doc README.md
%license LICENSE
%{python3_sitelib}/scdl
%{python3_sitelib}/scdl-%{version}.dist-info
%{_bindir}/scdl

%changelog
* Fri Sep 20 2024 Sebastian Wagner <sebix@sebix.at>
- require python3 >= 3.7
* Fri Sep 20 2024 Steve Kowalik <steven.kowalik@suse.com>
- Fix Requires to be python3-foo.
* Thu Sep 19 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.12.1:
  * Use tempdir for downloading
  * Set albumartist metadata for playlists
  * Migrate from cgi.parse_header to email.message.Message due to PEP 594
  * Use maintained dependencies
  * More consistent tag mapping
  * Added '--add-description' option
  * Add -q <search_query> command line argument
- Switch to pyproject macros.
- List directories in %%files explicitly.
* Sun Dec  4 2022 Dirk Müller <dmueller@suse.com>
- update to 2.7.3:
  * Removed download count check
* Sat Sep  3 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 2.7.2:
  - Update requirements
* Sun May 22 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 2.7.1:
  - Prefer filename* header (#416)
  * Prefer filename* header
  * Fix typo
  - Support wav file tagging (#417)
  - Update README
* Thu Apr  7 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 2.7.0:
  - New sync option (#374)
  - Fix offset for playlists
* Sat Feb 12 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- Fix offset for playlists
* Sat Jan 22 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- Fix downloading hidden tracks from a hidden playlist
* Tue Jan 18 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- Implement offset
* Sat Jan  8 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- Fix file size calculation
- update to version 2.5.2:
  - Fix downloading
  - Fix m4a downloading
* Wed Jan  5 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 2.5.0:
  - Reimplement --min-size and --max-size
  - Allow user to provide just username instead of soundcloud.com URL
  - Add --no-playlist option
  - Only publish on new tag pushed
* Mon Jan  3 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 2.4.0:
  - Fix '--no-playlist-folder' (#280)
  - Introduce support for HLS
  - Return filename from the download functon
  - Fix issues with utf8 paths from config
  - Fix --addtimestamp and already downloaded fail (#295)
  - Added -n option (#282)
  - Fix soundcloud url
  - fix #320, only get more info when needed
  - respect XDG_CONFIG_HOME environment variable (#312)
  - Fix original download detection
  - Add track number metadata when downloading playlists (#330)
  - Fix missing check for geoblocked tracks (#332) (#334)
  - Skip metadata if file already exist
  - Add a --force-metadata option to add the metadata to downloaded file
  - Add a --no-album-tag option to prevent track to get the same album ar…
  - Program should refuse to run with an informative error message if ffm…
  - added missing headers to another request (#385)
  - Reimplement 'me' downloading
  - Raise error if default config file cannot be read
  - Include default config file
  - Exit with message if ffmpeg is not installed
  - Add --strict option, shorten converted .flac filenames to 255 bytes
- Update to version v2.2.4
  - Better error handling, return exit code 1 on errors
  - Allow downloading of mobile links
  - Add support for Python 3.6
  - Add support for downloading original files with secret tokens
  - Prefer original file extension over mimetype guess
  - Download even if track is not streamable
  - Remove query string from input URL
  - Fix issue for limitting number of playlist entry downloads
  - Dynamically generate client_id if specified client_id is not valid
* Wed Nov  7 2018 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 1.6.12
* Sun Jan  8 2017 mrueckert@suse.de
- initial package
